import 'package:cpt_auth/modules/forgot_verify/forgot_verify_state.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:cs_resources/generated/l10n.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:plugin_basic/constants/app_constant.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_field.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/widget_export.dart';

import '../../router/page/auth_page_router.dart';
import 'forgot_verify_view_model.dart';

@RoutePage()
class ForgotVerifyPage extends HookConsumerWidget {
  final String? phone;

  const ForgotVerifyPage({Key? key, required this.phone}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context, required String? phone}) {
    if (context != null) {
      context.router.push(ForgotVerifyPageRoute(phone: phone));
    } else {
      appRouter.push(ForgotVerifyPageRoute(phone: phone));
    }
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final viewModel = ref.read(forgotVerifyViewModelProvider.notifier);
    final state = ref.watch(forgotVerifyViewModelProvider);

    return Scaffold(
      appBar: MyAppBar.appBar(context, ""),
      backgroundColor: context.appColors.backgroundDefault,
      body: SingleChildScrollView(
        scrollDirection: Axis.vertical,
        physics: const BouncingScrollPhysics(),
        child: Container(
          margin: const EdgeInsets.symmetric(horizontal: 38),
          width: double.infinity,
          child: Column(
            mainAxisSize: MainAxisSize.max,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              //顶部图片
              const MyAssetImage(
                Assets.authForgotResetPasswordImg,
                width: 260,
                height: 170,
              ).marginOnly(top: 25, bottom: 29),

              //提示文本
              MyTextView(
                S.current.mobile_phone,
                fontSize: 15,
                marginBottom: 23,
                isFontMedium: true,
                textColor: context.appColors.textBlack,
              ),

              MyTextView(
                "+${AppConstant.countryCode} ${phone ?? "-"}",
                fontSize: 23,
                marginBottom: 23,
                isFontMedium: true,
                textColor: context.appColors.textBlack,
              ),

              // 表单 - 验证码
              _buildInputLayout(
                context,
                state,
                "code",
                textInputType: TextInputType.number,
                textInputAction: TextInputAction.next,
                errorText: state.codeErrorText,
                showRightIcon: true,
                rightWidget: MyTextView(
                  state.isCounting ? "${state.countdownTime} s" : S.current.get_code,
                  textAlign: TextAlign.center,
                  textColor: context.appColors.textPrimary,
                  fontSize: 15,
                  paddingRight: 5,
                  isFontMedium: true,
                  onClick: state.isCounting ? null : () => viewModel.showVerifyCodedDialog(phone),
                ).paddingOnly(top: 15, bottom: 15),
                onSubmit: (formKey, value) {
                  state.formData[formKey]!['focusNode'].unfocus();
                  FocusScope.of(context).requestFocus(state.formData['password']!['focusNode']);
                },
              ),

              // 表单 - 重置密码
              _buildInputLayout(
                context,
                state,
                "password",
                marginTop: 15,
                obscureText: !state.pwdVisibility,
                errorText: state.passwordErrorText,
                textInputAction: TextInputAction.next,
                showRightIcon: true,
                rightWidget: IconButton(
                  highlightColor: Colors.transparent,
                  splashColor: Colors.transparent,
                  icon: state.pwdVisibility
                      ? const MyAssetImage(
                          Assets.authPasswordHide,
                          width: 22.5,
                          height: 16.5,
                        )
                      : const MyAssetImage(
                          Assets.authPasswordShow,
                          width: 22.5,
                          height: 16.5,
                        ),
                  onPressed: () {
                    viewModel.switchPwdVisibility();
                  },
                ),
                onSubmit: (formKey, value) {
                  state.formData[formKey]!['focusNode'].unfocus();
                  FocusScope.of(context).requestFocus(state.formData['confirm_password']!['focusNode']);
                },
              ),

              // 表单 - 确认密码
              _buildInputLayout(
                context,
                state,
                "confirm_password",
                marginTop: 15,
                obscureText: !state.confirmPwdVisibility,
                errorText: state.confirmPasswordErrorText,
                showRightIcon: true,
                rightWidget: IconButton(
                  highlightColor: Colors.transparent,
                  splashColor: Colors.transparent,
                  icon: state.confirmPwdVisibility
                      ? const MyAssetImage(
                          Assets.authPasswordHide,
                          width: 22.5,
                          height: 16.5,
                        )
                      : const MyAssetImage(
                          Assets.authPasswordShow,
                          width: 22.5,
                          height: 16.5,
                        ),
                  onPressed: () {
                    viewModel.switchConfirmPwdVisibility();
                  },
                ),
                onSubmit: (formKey, value) {
                  state.formData[formKey]!['focusNode'].unfocus();
                  viewModel.submitVerify(phone);
                },
              ),

              MyButton(
                onPressed: (){
                  viewModel.submitVerify(phone);
                },
                text: S.current.next,
                textColor: Colors.white,
                backgroundColor: context.appColors.btnBgDefault,
                fontWeight: FontWeight.w500,
                type: ClickType.throttle,
                fontSize: 16,
                minHeight: 50,
                radius: 5,
              ).marginOnly(top: 25, bottom: 30),
            ],
          ),
        ),
      ),
    );
  }

  /// 输入框
  Widget _buildInputLayout(
    BuildContext context,
    ForgotVerifyState state,
    String key, {
    double marginTop = 0,
    bool? showRightIcon = false, //是否展示右侧的布局
    Widget? rightWidget, //右侧的布局
    TextInputType textInputType = TextInputType.text,
    String? errorText,
    bool obscureText = false,
    TextInputAction textInputAction = TextInputAction.done,
    Function? onSubmit,
  }) {
    return IgnoreKeyboardDismiss(
      child: MyTextField(
        key,
        fillBackgroundColor: context.appColors.authFiledBG,
        state.formData[key]!['value'],
        hintText: state.formData[key]!['hintText'],
        hintStyle: TextStyle(
          color: context.appColors.authFiledHint,
          fontSize: 16.0,
          fontWeight: FontWeight.w500,
        ),
        controller: state.formData[key]!['controller'],
        focusNode: state.formData[key]!['focusNode'],
        margin: EdgeInsets.only(top: marginTop),
        padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 3),
        showDivider: false,
        height: 44,
        style: TextStyle(
          color: context.appColors.authFiledText,
          fontSize: 16.0,
          fontWeight: FontWeight.w500,
        ),
        inputType: textInputType,
        textInputAction: textInputAction,
        onSubmit: onSubmit,
        cursorColor: context.appColors.authFiledText,
        obscureText: obscureText,
        errorText: errorText,
        showLeftIcon: true,
        showRightIcon: showRightIcon,
        rightWidget: rightWidget,
      ),
    );
  }
}
